import { defineConfig } from "vite";
import laravel from "laravel-vite-plugin";
import vue from "@vitejs/plugin-vue";
import svgLoader from "vite-svg-loader";
import { fileURLToPath, URL } from "url";
import checker from "vite-plugin-checker";
import autoImport from "unplugin-auto-import/vite";

export default defineConfig(({ mode }) => ({
  build: {
    chunkSizeWarningLimit: 2048,
  },
  plugins: [
    laravel({
      input: ["resources/js/app.ts"],
      refresh: true,
    }),
    vue({
      template: {
        transformAssetUrls: {
          base: null,
          includeAbsolute: false,
        },
      },
    }),
    svgLoader({
      svgo: false,
    }),
    autoImport({
      dts: "./resources/js/types/auto-imports.d.ts",
      vueTemplate: true,
      imports: ["vue", "vue-i18n", "vue-router", "@vueuse/head"],
    }),
    mode === "development"
      ? checker({
          vueTsc: true,
          typescript: true,
          eslint: {
            lintCommand: 'eslint "./**/*.{ts,vue}"',
          },
        })
      : undefined,
  ],
  resolve: {
    alias: {
      "@/": fileURLToPath(new URL("./resources/", import.meta.url)),
    },
  },
  optimizeDeps: {
    include: ["lodash-es", "dayjs", "vue", "vue-router", "vue-i18n"],
  },
}));
